package org.jboss.remoting;

import java.util.TimerTask;

import org.jboss.logging.Logger;

import org.jboss.remoting.util.TimerUtil;

/**
 * Internal agent class to ping the remote server to keep lease alive.
 *
 * @author <a href="mailto:telrod@e2technologies.net">Tom Elrod</a>
 */
public class LeasePinger extends TimerTask
{
   private Client client = null;
   private long pingPeriod = -1;

   private static final Logger log = Logger.getLogger(LeasePinger.class);

   public LeasePinger(Client remotingClient)
   {
      this.client = remotingClient;
   }

   public void startPing(long leaseTimeout)
   {
      this.pingPeriod = leaseTimeout;
      TimerUtil.schedule(this, pingPeriod);
   }

   public void stopPing()
   {
      cancel();
   }

   public void run()
   {
      if(client != null)
      {
         try
         {
            client.invoke("$PING$");
         }
         catch(Throwable throwable)
         {
            //Don't swallow!
            log.warn("Error sending lease ping to server.");
         }
      }
   }
}
